<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sl_SI" sourcelanguage="en">
<context>
    <name>AgendaPlug</name>
    <message>
        <location filename="../AgendaPlug.cpp" line="28"/>
        <source>Jump to today</source>
        <translation>Pojdi na današnji dan</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="29"/>
        <source>Jump to</source>
        <translation>Pojdi na</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="30"/>
        <source>New event</source>
        <translation>Nov dogodek</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.h" line="20"/>
        <source>Agenda</source>
        <translation>Agenda</translation>
    </message>
</context>
<context>
    <name>AlarmPickDialog</name>
    <message>
        <location filename="../AlarmPickDialog.ui" line="6"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="38"/>
        <source>In advance</source>
        <translation>V naprej</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="48"/>
        <source>Arbitrary</source>
        <translation>Poljubno</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="66"/>
        <source>Hours</source>
        <translation>Ure</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="86"/>
        <source>Minutes</source>
        <translation>Minute</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="106"/>
        <source>Seconds</source>
        <translation>Sekunde</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="20"/>
        <source>Enable</source>
        <translation>Omogoči</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.cpp" line="15"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
</context>
<context>
    <name>AlarmPickSelector</name>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="152"/>
        <source>None</source>
        <translation>Nič</translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="164"/>
        <source>Exact</source>
        <translation>Točno</translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="166"/>
        <source>%n hour(s) before</source>
        <translation>
            <numerusform>pred %n uro</numerusform>
            <numerusform>pred %n urama</numerusform>
            <numerusform>pred %n urami</numerusform>
            <numerusform>pred %n urami</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="167"/>
        <source>%n minute(s) before</source>
        <translation>
            <numerusform>pred %n minuto</numerusform>
            <numerusform>pred %n minutama</numerusform>
            <numerusform>pred %n minutami</numerusform>
            <numerusform>pred %n minutami</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="168"/>
        <source>%n second(s) before</source>
        <translation>
            <numerusform>pred %n sekundo</numerusform>
            <numerusform>pred %n sekundama</numerusform>
            <numerusform>pred %n sekundami</numerusform>
            <numerusform>pred %n sekundami</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="170"/>
        <source>%1:%2:%3 before</source>
        <translation>%1:%2:%3 pred tem</translation>
    </message>
</context>
<context>
    <name>BirthdayEditDialog</name>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="6"/>
        <source>Edit event</source>
        <translation>Uredi dogodek</translation>
    </message>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="12"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
</context>
<context>
    <name>ByDayWidget</name>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="37"/>
        <source>From beginning</source>
        <translation>Od začetka</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="38"/>
        <source>From end</source>
        <translation>Od konca</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="49"/>
        <source>By day of month</source>
        <translation>Po dnevih v mesecu</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="51"/>
        <source>By week of year</source>
        <translation>Po tednih v letu</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="53"/>
        <source>By day of year</source>
        <translation>Po dnevih v letu</translation>
    </message>
</context>
<context>
    <name>ByMonthWidget</name>
    <message>
        <location filename="../recurrence/ByMonthWidget.cpp" line="20"/>
        <source>By month</source>
        <translation>Po mesecih</translation>
    </message>
</context>
<context>
    <name>ByWeekdayWidget</name>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="21"/>
        <source>By day of week</source>
        <translation>Po dnevih v tednu</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="55"/>
        <source>From beginning</source>
        <translation>Od začetka</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="56"/>
        <source>From end</source>
        <translation>Od konca</translation>
    </message>
</context>
<context>
    <name>CalendarEditDialog</name>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="52"/>
        <source>Edit calendar</source>
        <translation>Uredi koledar</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="27"/>
        <source>Local</source>
        <translation>Lokalno</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="37"/>
        <source>Birthday</source>
        <translation>Rojstni dan</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="53"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="63"/>
        <source>Visible</source>
        <translation>Vidno</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="42"/>
        <source>Export</source>
        <translation>Izvoz</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="43"/>
        <source>Delete</source>
        <translation>izbriši</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="90"/>
        <source>New calendar</source>
        <translation>Nov koledar</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="94"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="141"/>
        <location filename="../settings/CalendarEditDialog.cpp" line="166"/>
        <source>Error occurred</source>
        <translation>Prišlo je do napake</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="175"/>
        <source>Save file</source>
        <translation>Shrani datoteko</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="193"/>
        <source>This calendar cannot be deleted. Delete all calendar content instead?</source>
        <translation>Koledarja ni možno izbrisati. Ali namesto tega pobrišem vsebino koledarja?</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="201"/>
        <source>Delete this calendar and its events, tasks and notes?</source>
        <translation>Izbrišem koledar in vse dogodke, opravila in beležke?</translation>
    </message>
</context>
<context>
    <name>CalendarPickDialog</name>
    <message>
        <location filename="../CalendarPickDialog.ui" line="6"/>
        <source>Calendar</source>
        <translation>Koledar</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigDialog</name>
    <message>
        <location filename="../settings/CalendarsConfigDialog.ui" line="6"/>
        <source>Edit calendars</source>
        <translation>Uredi koledarje</translation>
    </message>
    <message>
        <location filename="../settings/CalendarsConfigDialog.cpp" line="27"/>
        <source>New</source>
        <translation>Nov</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigSelector</name>
    <message numerus="yes">
        <location filename="../settings/CalendarsConfigSelector.cpp" line="16"/>
        <source>%n visible</source>
        <translation>
            <numerusform>%n viden</numerusform>
            <numerusform>%n vidna</numerusform>
            <numerusform>%n vidni</numerusform>
            <numerusform>%n vidnih</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ChangeManager</name>
    <message>
        <location filename="../ChangeManager.cpp" line="239"/>
        <source>Delete event?</source>
        <translation>Izbrišem dogodek?</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="242"/>
        <source>Delete task?</source>
        <translation>Izbrišem opravilo?</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="245"/>
        <source>Delete note?</source>
        <translation>Izbrišem beležko?</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="248"/>
        <source>Delete component?</source>
        <translation>Izbrišem gradnik?</translation>
    </message>
</context>
<context>
    <name>ColorPickDialog</name>
    <message>
        <location filename="../ColorPickDialog.ui" line="6"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <location filename="../ColorPickDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
</context>
<context>
    <name>ComponentEditDialog</name>
    <message>
        <location filename="../ComponentEditDialog.h" line="22"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../ComponentEditDialog.h" line="29"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>ComponentListDelegate</name>
    <message>
        <location filename="../ComponentListDelegate.h" line="80"/>
        <source>All
day</source>
        <translation>Cel
dan</translation>
    </message>
</context>
<context>
    <name>ComponentListWidget</name>
    <message>
        <location filename="../ComponentListWidget.cpp" line="71"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="72"/>
        <source>Clone</source>
        <translation>Podvoji</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="73"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>ComponentWidget</name>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="183"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="184"/>
        <source>Clone</source>
        <translation>Podvoji</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="185"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>DateFormatDialog</name>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="6"/>
        <source>Date formats</source>
        <translation>Zapisi datumov</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="20"/>
        <source>Full</source>
        <translation>Polno</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="37"/>
        <source>Partial</source>
        <translation>Delno</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="72"/>
        <source>Day</source>
        <translation>Dan</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="89"/>
        <source>Month</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="106"/>
        <source>Year</source>
        <translation>Leto</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.cpp" line="24"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
</context>
<context>
    <name>DatePickDialog</name>
    <message>
        <location filename="../DatePickDialog.cpp" line="16"/>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="161"/>
        <source>Week %1 (%2 - %3)</source>
        <translation>Teden %1 (%2 - %3)</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="19"/>
        <source>Select date</source>
        <translation>Izberi datum</translation>
    </message>
</context>
<context>
    <name>DateTimePickDialog</name>
    <message>
        <location filename="../DateTimePickDialog.cpp" line="15"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
</context>
<context>
    <name>DayNumberDialog</name>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="17"/>
        <source>Enter day number</source>
        <translation>Vnesi številko dneva</translation>
    </message>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="24"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
</context>
<context>
    <name>DayWindow</name>
    <message>
        <location filename="../DayWindow.ui" line="35"/>
        <source>Previous day</source>
        <translation>Prejšnji dan</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="40"/>
        <source>Next day</source>
        <translation>Naslednji dan</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="45"/>
        <source>Jump to today</source>
        <translation>Pojdi na današnji dan</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="50"/>
        <source>Jump to</source>
        <translation>Pojdi na</translation>
    </message>
</context>
<context>
    <name>DetailedCalendarDelegate</name>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="30"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n dogodek</numerusform>
            <numerusform>%n dogodka</numerusform>
            <numerusform>%n dogodki</numerusform>
            <numerusform>%n dogodkov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="31"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n opravilo</numerusform>
            <numerusform>%n opravili</numerusform>
            <numerusform>%n opravila</numerusform>
            <numerusform>%n opravil</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="32"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n beležka</numerusform>
            <numerusform>%n beležki</numerusform>
            <numerusform>%n beležke</numerusform>
            <numerusform>%n beležk</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>EventEditDialog</name>
    <message>
        <location filename="../EventEditDialog.ui" line="27"/>
        <source>Title</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="40"/>
        <source>Where</source>
        <translation>Kje</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="55"/>
        <source>All day</source>
        <translation>Cel dan</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="64"/>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="90"/>
        <source>To</source>
        <translation>Za</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="118"/>
        <source>Time zone</source>
        <translation>Časovni pas</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="125"/>
        <source>Repeat</source>
        <translation>Ponovi</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="135"/>
        <source>Calendar</source>
        <translation>Koledar</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="142"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="149"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="30"/>
        <source>Edit event</source>
        <translation>Uredi dogodek</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="33"/>
        <source>New event</source>
        <translation>Nov dogodek</translation>
    </message>
</context>
<context>
    <name>EventWindow</name>
    <message>
        <location filename="../EventWindow.ui" line="6"/>
        <source>Event</source>
        <translation>Dogodek</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="62"/>
        <source>To</source>
        <translation>Za</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="86"/>
        <source>Repeat</source>
        <translation>Ponovi</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="110"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="182"/>
        <source>Previous event</source>
        <translation>Prejšnji dogodek</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="187"/>
        <source>Next event</source>
        <translation>Naslednji dogodek</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="192"/>
        <source>Edit event</source>
        <translation>Uredi dogodek</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="197"/>
        <source>Delete event</source>
        <translation>Izbriši dogodek</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="202"/>
        <source>Clone event</source>
        <translation>Podvoji dogodek</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="207"/>
        <source>Automatic links</source>
        <translation>Samodejne povezave</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="149"/>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="149"/>
        <source>On</source>
        <translation>Na</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="219"/>
        <location filename="../EventWindow.cpp" line="240"/>
        <source>No more events</source>
        <translation>Ni dogodkov</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="271"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="272"/>
        <source>Clone</source>
        <translation>Podvoji</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="273"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="../ImportDialog.ui" line="6"/>
        <source>Select calendar</source>
        <translation>Izberi koledar</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="44"/>
        <source>Import</source>
        <translation>Uvozi</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="50"/>
        <source>New calendar</source>
        <translation>Nov koledar</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="77"/>
        <source>Importing aborted</source>
        <translation>Ovoz prekinjen</translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="112"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n dogodek</numerusform>
            <numerusform>%n dogodka</numerusform>
            <numerusform>%n dogodki</numerusform>
            <numerusform>%n dogodkov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="113"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n opravilo</numerusform>
            <numerusform>%n opravili</numerusform>
            <numerusform>%n opravila</numerusform>
            <numerusform>%n opravil</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="114"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n beležka</numerusform>
            <numerusform>%n beležki</numerusform>
            <numerusform>%n beležke</numerusform>
            <numerusform>%n beležk</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="126"/>
        <location filename="../ImportDialog.cpp" line="194"/>
        <source>Error occurred</source>
        <translation>Prišlo je do napake</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="187"/>
        <source>Some items already in calendar</source>
        <translation>Nekateri dogodki so že v koledarju</translation>
    </message>
</context>
<context>
    <name>JournalEditDialog</name>
    <message>
        <location filename="../JournalEditDialog.ui" line="22"/>
        <source>Calendar</source>
        <translation>Koledar</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="21"/>
        <source>Edit note</source>
        <translation>Uredi beležko</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="24"/>
        <source>New note</source>
        <translation>Nova beležka</translation>
    </message>
</context>
<context>
    <name>JournalsPlug</name>
    <message>
        <location filename="../JournalsPlug.cpp" line="28"/>
        <source>New note</source>
        <translation>Nova beležka</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="47"/>
        <source>Notes</source>
        <translation>Beležke</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="124"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="125"/>
        <source>Clone</source>
        <translation>Podvoji</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="126"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="63"/>
        <source>Month</source>
        <translation>Mesec</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="64"/>
        <source>Week</source>
        <translation>Teden</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="65"/>
        <source>Agenda</source>
        <translation>Agenda</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="66"/>
        <source>Tasks</source>
        <translation>Opravilo</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="67"/>
        <source>Notes</source>
        <translation>Beležke</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="68"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
</context>
<context>
    <name>MonthPlug</name>
    <message>
        <location filename="../month/MonthPlug.cpp" line="60"/>
        <source>Previous month</source>
        <translation>Prejšnji mesec</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="61"/>
        <source>Next month</source>
        <translation>Naslednji mesec</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="62"/>
        <source>Jump to today</source>
        <translation>Pojdi na današnji dan</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="63"/>
        <source>Jump to</source>
        <translation>Pojdi na</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="64"/>
        <source>New event</source>
        <translation>Nov dogodek</translation>
    </message>
</context>
<context>
    <name>NewComponentWidget</name>
    <message>
        <location filename="../NewComponentWidget.h" line="24"/>
        <source>New event</source>
        <translation>Nov dogodek</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../CWrapper.h" line="59"/>
        <source>Private</source>
        <translation>Zasebno</translation>
    </message>
    <message>
        <location filename="../CWrapper.h" line="61"/>
        <source>Birthdays</source>
        <translation>Rojstni dnevi</translation>
    </message>
</context>
<context>
    <name>RecurrencePickDialog</name>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="6"/>
        <source>Recurrence</source>
        <translation>Ponavljanje</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="24"/>
        <source>Repeat</source>
        <translation>Ponovi</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="34"/>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="55"/>
        <source>Frequency</source>
        <translation>pogostost</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
        <source>Daily</source>
        <translation>Dnevno</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
        <source>Weekly</source>
        <translation>Tedensko</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
        <source>Monthly</source>
        <translation>Mesečno</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="81"/>
        <source>Yearly</source>
        <translation>Letno</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="89"/>
        <source>Interval</source>
        <translation>Interval</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
        <source>Forever</source>
        <translation>Za vedno</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
        <source>Until</source>
        <translation>Do</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="123"/>
        <source>Count</source>
        <translation>Štej</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="188"/>
        <source>Week start</source>
        <translation>Začetek tedna</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.cpp" line="36"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
</context>
<context>
    <name>RecurrencePickSelector</name>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="37"/>
        <source>Never</source>
        <translation>Nikoli</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="39"/>
        <source>External</source>
        <translation>Zunanje</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="41"/>
        <source>Every day</source>
        <translation>Vsak dan</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="43"/>
        <source>Every workday</source>
        <translation>Vsak delovni dan</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="45"/>
        <source>Every week</source>
        <translation>Vsak teden</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="47"/>
        <source>Every month</source>
        <translation>Vsak mesec</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="49"/>
        <source>Every year</source>
        <translation>Vsako leto</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="51"/>
        <source>Complex</source>
        <translation>Kompleksno</translation>
    </message>
</context>
<context>
    <name>RulePickDialog</name>
    <message>
        <location filename="../recurrence/RulePickDialog.ui" line="6"/>
        <source>Select rule</source>
        <translation>Izberi pravilo</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="16"/>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="17"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
</context>
<context>
    <name>RulePickSelector</name>
    <message>
        <location filename="../recurrence/RulePickSelector.cpp" line="14"/>
        <source>Rule %1 of %2</source>
        <translation>Pravilo %1 od %2</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="6"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="31"/>
        <source>Edit calendars</source>
        <translation>Uredi koledarje</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="41"/>
        <source>Alarm tone</source>
        <translation>Zvok alarma</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="51"/>
        <source>Delete events</source>
        <translation>Izbriši dogodke</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="61"/>
        <source>Delete tasks</source>
        <translation>Izbriši opravila</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="71"/>
        <source>First day of week</source>
        <translation>Prvi dan v tednu</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="81"/>
        <source>Editable time zones</source>
        <translation>Urejanje časovnih pasov</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="88"/>
        <source>Date formats</source>
        <translation>Zapisi datumov</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="19"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="66"/>
        <source>Never</source>
        <translation>Nikoli</translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="68"/>
        <location filename="../settings/SettingsDialog.cpp" line="70"/>
        <source>Older than %n week(s)</source>
        <translation>
            <numerusform>Starejše kot %n teden</numerusform>
            <numerusform>Starejše kot %n tedna</numerusform>
            <numerusform>Starejše kot %n tedne</numerusform>
            <numerusform>Starejše kot %n tednov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="72"/>
        <source>Older than %n month(s)</source>
        <translation>
            <numerusform>Starejše kot %n mesec</numerusform>
            <numerusform>Starejše kot %n meseca</numerusform>
            <numerusform>Starejše kot %n mesece</numerusform>
            <numerusform>Starejše kot %n mesecev</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="74"/>
        <source>Older than %n year(s)</source>
        <translation>
            <numerusform>Starejše kot %n leto</numerusform>
            <numerusform>Starejše kot %n leti</numerusform>
            <numerusform>Starejše kot %n leta</numerusform>
            <numerusform>Starejše kot %n let</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TimePickDialog</name>
    <message>
        <location filename="../TimePickDialog.cpp" line="11"/>
        <source>Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimePickDialog.cpp" line="13"/>
        <source>Select time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TodoEditDialog</name>
    <message>
        <location filename="../TodoEditDialog.ui" line="28"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="35"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="42"/>
        <source>Time zone</source>
        <translation>Časovni pas</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="49"/>
        <source>Calendar</source>
        <translation>Koledar</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="56"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="63"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="28"/>
        <source>Edit task</source>
        <translation>Uredi opravilo</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="31"/>
        <source>New task</source>
        <translation>Novo opravilo</translation>
    </message>
</context>
<context>
    <name>TodoWindow</name>
    <message>
        <location filename="../TodoWindow.ui" line="6"/>
        <source>Task</source>
        <translation>Opravilo</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="41"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="50"/>
        <source>Due</source>
        <translation>Do</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="80"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="169"/>
        <source>Edit task</source>
        <translation>Uredi opravilo</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="174"/>
        <source>Delete task</source>
        <translation>Izbriši opravilo</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="179"/>
        <source>Clone task</source>
        <translation>Podvoji opravilo</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="184"/>
        <source>Automatic links</source>
        <translation>Samodejne povezave</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="171"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="172"/>
        <source>Clone</source>
        <translation>Podvoji</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="173"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>TodosPlug</name>
    <message>
        <location filename="../TodosPlug.cpp" line="34"/>
        <location filename="../TodosPlug.cpp" line="329"/>
        <source>New task</source>
        <translation>Novo opravilo</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="41"/>
        <source>Hide completed</source>
        <translation>Skrij končano</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="42"/>
        <source>Group by calendar</source>
        <translation>Združi po koledarju</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="43"/>
        <source>Delete completed</source>
        <translation>Izbriši končano</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="71"/>
        <source>Tasks</source>
        <translation>Opravila</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="332"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="333"/>
        <source>Clone</source>
        <translation>Podvoji</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="334"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="379"/>
        <source>Delete completed tasks from all calendars?</source>
        <translation>Izbrišem končana opravila iz vseh koledarjev?</translation>
    </message>
</context>
<context>
    <name>TunePickDialog</name>
    <message>
        <location filename="../settings/TunePickDialog.ui" line="6"/>
        <source>Choose alarm tone</source>
        <translation>Izberi ton alarma</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="17"/>
        <source>More</source>
        <translation>Več</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="67"/>
        <source>Add alarm tone</source>
        <translation>Dodaj ton alarma</translation>
    </message>
</context>
<context>
    <name>WeekButton</name>
    <message>
        <location filename="../month/WeekButton.cpp" line="33"/>
        <source>w%1</source>
        <translation>t%1</translation>
    </message>
</context>
<context>
    <name>WeekPlug</name>
    <message>
        <location filename="../week/WeekPlug.cpp" line="43"/>
        <source>Previous week</source>
        <translation>Prejšnji teden</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="44"/>
        <source>Next week</source>
        <translation>Naslednji teden</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="45"/>
        <source>Jump to today</source>
        <translation>Pojdi na današnji dan</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="46"/>
        <source>Jump to</source>
        <translation>Pojdi na</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="47"/>
        <source>New event</source>
        <translation>Nov dogodek</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="70"/>
        <source>Week %1 (%2)</source>
        <translation>Teden %1 (%2)</translation>
    </message>
</context>
<context>
    <name>WeekWidget</name>
    <message>
        <location filename="../week/WeekWidget.cpp" line="364"/>
        <source>All day</source>
        <translation>Cel dan</translation>
    </message>
</context>
<context>
    <name>ZonePickDialog</name>
    <message>
        <location filename="../ZonePickDialog.ui" line="6"/>
        <source>Time zone</source>
        <translation>Časovni pas</translation>
    </message>
    <message>
        <location filename="../ZonePickDialog.ui" line="39"/>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <location filename="../ZonePickDialog.cpp" line="79"/>
        <source>Current</source>
        <translation>Trenutno</translation>
    </message>
</context>
</TS>
